# Installation

## Stable release

To install AirField, run this command in your terminal:

```sh
uv add AirField
```

Or if you prefer to use `pip`:

```sh
pip install AirField
```

## From source

The source files for AirField can be downloaded from the [Github repo](https://github.com/feldroy/AirField).

You can either clone the public repository:

```sh
git clone https://github.com/feldroy/AirField
```

Or download the [tarball](https://github.com/feldroy/AirField/tarball/main):

```sh
curl -OJL https://github.com/feldroy/AirField/tarball/main
```

Once you have a copy of the source, you can install it with:

```sh
cd AirField
uv sync
```
